@@ -8,9 +8,6 @@
 
 """Invenio module to ease the creation and management of applications."""
 
-from __future__ import absolute_import, print_function
-
-from .ext import InvenioCli
 from .version import __version__
 
-__all__ = ('__version__', 'InvenioCli')
+__all__ = ('__version__',)
